@@ -9,7 +9,7 @@ class TestSanity(PillowTestCase):
     def test_sanity(self):
 
         # Make sure we have the binary extension
-        im = PIL.Image.core.new("L", (100, 100))
+        PIL.Image.core.new("L", (100, 100))
 
         self.assertEqual(PIL.Image.VERSION[:3], '1.1')
 
@@ -19,11 +19,11 @@ class TestSanity(PillowTestCase):
         self.assertEqual(len(im.tobytes()), 1300)
 
         # Create images in all remaining major modes.
-        im = PIL.Image.new("L", (100, 100))
-        im = PIL.Image.new("P", (100, 100))
-        im = PIL.Image.new("RGB", (100, 100))
-        im = PIL.Image.new("I", (100, 100))
-        im = PIL.Image.new("F", (100, 100))
+        PIL.Image.new("L", (100, 100))
+        PIL.Image.new("P", (100, 100))
+        PIL.Image.new("RGB", (100, 100))
+        PIL.Image.new("I", (100, 100))
+        PIL.Image.new("F", (100, 100))
 
 
 if __name__ == '__main__':
